package data.scripts.campaign.customstart;

import com.fs.starfarer.api.Global;
import com.fs.starfarer.api.Script;
import com.fs.starfarer.api.campaign.CampaignFleetAPI;
import com.fs.starfarer.api.campaign.CargoAPI;
import com.fs.starfarer.api.campaign.InteractionDialogAPI;
import com.fs.starfarer.api.campaign.SpecialItemData;
import com.fs.starfarer.api.campaign.rules.MemoryAPI;
import com.fs.starfarer.api.characters.CharacterCreationData;
import com.fs.starfarer.api.characters.MutableCharacterStatsAPI;
import com.fs.starfarer.api.fleet.FleetMemberAPI;
import com.fs.starfarer.api.impl.campaign.ids.Factions;
import com.fs.starfarer.api.impl.campaign.ids.Skills;
import com.fs.starfarer.api.impl.campaign.rulecmd.AddRemoveCommodity;
import com.fs.starfarer.api.impl.campaign.rulecmd.FireBest;
import com.fs.starfarer.api.impl.campaign.rulecmd.newgame.NGCAddStartingShipsByFleetType;
import exerelin.campaign.ExerelinSetupData;
import exerelin.campaign.PlayerFactionStore;
import exerelin.campaign.customstart.CustomStart;
import exerelin.utilities.StringHelper;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

public class CswpAIResearcherStart extends CustomStart {
    protected List<String> ships = new ArrayList<>(Arrays.asList("apogee_Balanced", "fulgent_Assault", "glimmer_Assault"));

    public void execute(InteractionDialogAPI dialog, Map<String, MemoryAPI> memoryMap) {
        CharacterCreationData data = (CharacterCreationData) ((MemoryAPI) memoryMap.get("local")).get("$characterData");
        NGCAddStartingShipsByFleetType.generateFleetFromVariantIds(dialog, data, null, this.ships);
        NGCAddStartingShipsByFleetType.addStartingDModScript(memoryMap.get("local"));

        data.getStartingCargo().getCredits().add(75000);
        AddRemoveCommodity.addCreditsGainText(75000, dialog.getTextPanel());
        MutableCharacterStatsAPI stats = data.getPerson().getStats();
        stats.setLevel(3);
        stats.addPoints(2);
        stats.addStoryPoints(8);
        stats.setSkillLevel(Skills.AUTOMATED_SHIPS, 1);

        data.getStartingCargo().addSpecial(new SpecialItemData("cswp_derelict_bp_package", null), 1.0F);
        data.getStartingCargo().addSpecial(new SpecialItemData("cswp_domres_bp_package", null), 1.0F);
        data.getStartingCargo().addSpecial(new SpecialItemData("cswp_remnants_bp_package", null), 1.0F);
        data.getStartingCargo().addSpecial(new SpecialItemData("cswp_remnants_weapons_bp_package", null), 1.0F);
        data.getStartingCargo().addItems(CargoAPI.CargoItemType.RESOURCES, "alpha_core", 1.0F);
        data.getStartingCargo().addItems(CargoAPI.CargoItemType.RESOURCES, "beta_core", 2.0F);
        data.getStartingCargo().addItems(CargoAPI.CargoItemType.RESOURCES, "gamma_core", 5.0F);
        AddRemoveCommodity.addCommodityGainText("alpha_core", 1, dialog.getTextPanel());
        AddRemoveCommodity.addCommodityGainText("beta_core", 2, dialog.getTextPanel());
        AddRemoveCommodity.addCommodityGainText("gamma_core", 5, dialog.getTextPanel());

        // enforce normal difficulty
        data.setDifficulty("normal");
        ExerelinSetupData.getInstance().easyMode = false;
        PlayerFactionStore.setPlayerFactionIdNGC(Factions.PLAYER);
        ExerelinSetupData.getInstance().freeStart = true;

        dialog.getOptionPanel().addOption(StringHelper.getString("done", true), "nex_NGCDone");
        dialog.getOptionPanel().addOption(StringHelper.getString("back", true), "nex_NGCStartBack");
    }
}
